==> haskell-html-conduit-1.2.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.2.1.2
id: html-conduit-1.2.1.2-1H7YtIZAS0N2RWByIEs6Tp
key: html-conduit-1.2.1.2-1H7YtIZAS0N2RWByIEs6Tp
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags.
category: Web, Text, Conduit
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.HTML.DOM
abi: 901e9177c68b397ef18c39bcc477145a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/html-conduit-1.2.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/html-conduit-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/html-conduit-1.2.1.2
hs-libraries: HShtml-conduit-1.2.1.2-1H7YtIZAS0N2RWByIEs6Tp
depends:
    base-4.10.1.0 transformers-0.5.2.0 bytestring-0.10.8.2
    containers-0.5.10.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    resourcet-1.1.10-9ZnD9eSbn8b2f4IrDnWp0t
    conduit-1.2.12.1-BcLGeTf7mkLAqHbUwhBWCt
    conduit-extra-1.2.3.2-GWLT1A9X8hC5E20L0lHyhp
    xml-conduit-1.7.0.1-GTLu4x4lktu6EQlaBjDA2l
    tagstream-conduit-0.5.5.3-qV2SIgA2H4G42DBi8Ea8B
    xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             resourcet-1.1.10-9ZnD9eSbn8b2f4IrDnWp0t=f535b5e5a897661c493ba14a3655526f
             conduit-1.2.12.1-BcLGeTf7mkLAqHbUwhBWCt=11f5959f328c663d7ee883702af377dd
             conduit-extra-1.2.3.2-GWLT1A9X8hC5E20L0lHyhp=e684201738eb35e1a68fb83b0761535e
             xml-conduit-1.7.0.1-GTLu4x4lktu6EQlaBjDA2l=cf4e914fc784290b21bd4b5c239de3c0
             tagstream-conduit-0.5.5.3-qV2SIgA2H4G42DBi8Ea8B=563b5aedfec534fea5f6e9fa54bd9aba
             xml-types-0.3.6-8U94ZZax169GYLVDpT1mig=d5c752ba65b163e7bdddd7a60950098d
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.2.1.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.2.1.2
id: html-conduit-1.2.1.2-HIsVBhtlTx4IthXRaRBf5r
key: html-conduit-1.2.1.2-HIsVBhtlTx4IthXRaRBf5r
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags.
category: Web, Text, Conduit
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.HTML.DOM
abi: c99becf0069ef3800c260a7a916effe7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/html-conduit-1.2.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/html-conduit-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/html-conduit-1.2.1.2
hs-libraries: HShtml-conduit-1.2.1.2-HIsVBhtlTx4IthXRaRBf5r
depends:
    base-4.10.1.0 transformers-0.5.2.0 bytestring-0.10.8.2
    containers-0.5.10.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    resourcet-1.1.11-79hQ3yPKnHILm6C59MJDsm
    conduit-1.2.13-DezMow12UGZEaPPD4QZvMV
    conduit-extra-1.2.3.2-h2ylDfwpdMCaWkDyKk32a
    xml-conduit-1.7.1.2-6gFQiws3x8MLTlTZidb1ra
    tagstream-conduit-0.5.5.3-8Th0FFApAJJF0wVIszLbli
    xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             resourcet-1.1.11-79hQ3yPKnHILm6C59MJDsm=e7f391455a5a4368bb671aaa21bb55c6
             conduit-1.2.13-DezMow12UGZEaPPD4QZvMV=f46d6093f1359deab47b6b9dafbabaa1
             conduit-extra-1.2.3.2-h2ylDfwpdMCaWkDyKk32a=fdf53d1fcac1a9070d52e33e5eb8dd1a
             xml-conduit-1.7.1.2-6gFQiws3x8MLTlTZidb1ra=21d9e81735218f62ef130b0585c8e2ee
             tagstream-conduit-0.5.5.3-8Th0FFApAJJF0wVIszLbli=999c7dd5d52cfa260ea3469d19d8e04b
             xml-types-0.3.6-8U94ZZax169GYLVDpT1mig=d5c752ba65b163e7bdddd7a60950098d
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
